"""
Let's Encrypt 证书申请
"""
from argparse import ArgumentParser, Namespace
from encodings.punycode import T
import sys
from src.logger import get_logger, run_cmd_with_log
logger = get_logger(__name__)

class CertbotConfigurator:
    """
    Let's Encrypt 证书申请
    """
    def __init__(self,
                 domain: str = "*.zzyxyz.com",
                 acme_server: str = "https://acme-v02.api.letsencrypt.org/directory",
                 hook_auth_script: str = "./dns-hook.sh add",
                 hook_cleanup_script: str = "./dns-hook.sh remove"):
        self.domain = domain
        self.acme_server = acme_server
        self.hook_auth_script = hook_auth_script
        self.hook_cleanup_script = hook_cleanup_script
    @staticmethod
    def check_certbot() -> bool:
        """增强版环境检查"""
        try:
            # 检查安装和权限
            result = run_cmd_with_log(["certbot", "--version"], logger)
            return "certbot" in result.stdout.decode().lower()
        except (FileNotFoundError, PermissionError) as e:
            logger.error("Certbot 依赖检查失败, 可能需要检查文件是否存在或是否有可执行权限: %s", str(e))
            return False
    def run(self):
        """runing certbot to get cert"""
        # self.check_certbot()
        cmd = [
            "certbot",
            "certonly",
            "--manual",
            "--preferred-challenges", "dns",
            "--server", self.acme_server,
            "--manual-auth-hook", self.hook_auth_script,
            "--manual-cleanup-hook", self.hook_cleanup_script,
            "-d", self.domain
        ]
        # 过滤空字符串
        result = run_cmd_with_log([x for x in cmd if x], logger)
        if result.returncode != 0:
            logger.error("Certbot certonly failed %s", result.stderr)
            return False
        logger.info("Certbot certonly success")
        return True

def handle_certbot(args):
    """证书管理核心逻辑"""
    conf = CertbotConfigurator()
    if args.run:
        conf.run()
    return True

def parse_certbot(args: Namespace):
    """parse subcommand args"""
    if args.certbot:
        args.handler(args)
        sys.exit(0)

def register_certbot(parsers: ArgumentParser):
    """注册certbot子命令"""
    subparsers = parsers.add_subparsers(dest='certbot', required=False)
    parser = subparsers.add_parser('certbot', help='证书管理')
    parser.add_argument('--run', action='store_true', help='运行证书申请程序')
    parser.add_argument('--domain', required=False, help='目标域名')
    parser.set_defaults(handler=handle_certbot)  # 直接绑定处理函数
