"""
统一日志工具
"""
import logging
import subprocess

class ColorFormatter(logging.Formatter):
    """
    using terminal color to print colorful log
    """
    COLORS = {
        'WARNING': '\033[93m',
        'ERROR': '\033[91m',
        'CRITICAL': '\033[91m',
        'INFO': '\033[94m',
        'DEBUG': '\033[92m',
        'ENDC': '\033[0m'
    }

    def format(self, record):
        color = self.COLORS.get(record.levelname, '')
        message = super().format(record)
        return f"{color}{message}{self.COLORS['ENDC']}" if color else message

def get_logger(name: str | None = None):
    """
    using ColorFormatter to print colorful log
    """
    logger = logging.getLogger(name)
    logger.setLevel(logging.INFO)
    handler = logging.StreamHandler()
    handler.setFormatter(ColorFormatter('[%(asctime)s] %(levelname)s: %(message)s',
                                        datefmt='%Y-%m-%d %H:%M:%S'))
    logger.addHandler(handler)
    return logger

def run_cmd_with_log(cmd: list[str], logger: logging.Logger) -> subprocess.CompletedProcess[bytes]:
    """
    run cmd with log
    """
    logger.debug(f"Running command: {cmd}")
    try:
        result = subprocess.run(
                cmd,
                capture_output=True,
                stdout=None,
                stderr=None,
                check=False,
                text=True,
                timeout=3,
            )
    except (subprocess.SubprocessError, FileNotFoundError) as e:
        logger.debug(f"Command failed: {e}")
        return subprocess.CompletedProcess(cmd, returncode=-1, stdout='', stderr=str(e))
    if result.returncode != 0:
        logger.debug(f"""
        Command failed with exit code {result.returncode}
        stdout: {result.stdout}
        stderr: {result.stderr}
        """.strip())
    return result
